export const themeConfig = {
  siteTitle: 'Nexios',
  logo: '/logo.png',
  favicon: '/logo.png',
  themeSwitcher: true,

  socialLinks: [
    { icon: "github", link: "https://github.com/nexios-labs/nexios" },
    { icon: "twitter", link: "https://twitter.com/nexioslabs" },
  ],

  search: {
    provider: 'local'
  }
}
